import { type Driver, type DriverClientEventEmitter, type DriverClientState, type DriverQueryResult, type DriverStream, type DriverStreamResult } from '@slonik/driver';
export type ConnectionPoolClient = {
    acquire: () => void;
    destroy: () => Promise<void>;
    id: () => string;
    off: DriverClientEventEmitter['off'];
    on: DriverClientEventEmitter['on'];
    query: (query: string, values?: unknown[]) => Promise<DriverQueryResult>;
    release: () => Promise<void>;
    removeListener: DriverClientEventEmitter['removeListener'];
    state: () => DriverClientState;
    stream: (query: string, values?: unknown[]) => DriverStream<DriverStreamResult>;
};
type ConnectionPoolStateName = 'ACTIVE' | 'ENDING' | 'ENDED';
/**
 * @property {number} acquiredConnections - The number of connections that are currently acquired.
 */
type ConnectionPoolState = {
    acquiredConnections: number;
    idleConnections: number;
    pendingDestroyConnections: number;
    pendingReleaseConnections: number;
    state: ConnectionPoolStateName;
    waitingClients: number;
};
export type ConnectionPool = {
    acquire: () => Promise<ConnectionPoolClient>;
    end: () => Promise<void>;
    id: () => string;
    state: () => ConnectionPoolState;
};
export declare const createConnectionPool: ({ driver, poolSize, }: {
    driver: Driver;
    idleTimeout?: number;
    poolSize?: number;
}) => ConnectionPool;
export {};
//# sourceMappingURL=createConnectionPool.d.ts.map